@@ -1,5 +1,3 @@
-from typing import List, Dict, Optional, Tuple
-
 import erdb.effect_parser.attribute_fields as attrib_fields
 import erdb.effect_parser.parsers as parse
 import erdb.effect_parser.hardcoded as hardcoded_effects
@@ -10,9 +8,9 @@ from erdb.typing.enums import SpEffectType, AttackCondition
 from erdb.typing.effects import SchemaEffect
 
 
-_REFERENCE_EFFECT_PARAMS: List[str] = ["cycleOccurrenceSpEffectId", "applyIdOnGetSoul"]
+_REFERENCE_EFFECT_PARAMS: list[str] = ["cycleOccurrenceSpEffectId", "applyIdOnGetSoul"]
 
-_SP_EFFECT_TO_FIELD: Dict[SpEffectType, str] = {
+_SP_EFFECT_TO_FIELD: dict[SpEffectType, str] = {
     SpEffectType.HEMORRHAGE: "bloodAttackPower",
     SpEffectType.FROSTBITE: "freezeAttackPower",
     SpEffectType.POISON: "poizonAttackPower",
@@ -22,7 +20,7 @@ _SP_EFFECT_TO_FIELD: Dict[SpEffectType, str] = {
     SpEffectType.BLIGHT: "curseAttackPower",
 }
 
-_SP_EFFECT_TO_STR: Dict[SpEffectType, str] = {
+_SP_EFFECT_TO_STR: dict[SpEffectType, str] = {
     SpEffectType.HEMORRHAGE: "bleed",
     SpEffectType.FROSTBITE: "frostbite",
     SpEffectType.POISON: "poison",
@@ -32,7 +30,7 @@ _SP_EFFECT_TO_STR: Dict[SpEffectType, str] = {
     SpEffectType.BLIGHT: "death_blight",
 }
 
-def get_effects(sp_effect: ParamRow, sp_effect_type: SpEffectType, triggeree: Optional[ParamRow]=None, init_conditions: Optional[List[str]]=None) -> List[SchemaEffect]:
+def get_effects(sp_effect: ParamRow, sp_effect_type: SpEffectType, triggeree: ParamRow | None = None, init_conditions: list[str] | None = None) -> list[SchemaEffect]:
     effects = hardcoded_effects.get(sp_effect.index, sp_effect_type)
 
     for field, attrib_field in attrib_fields.get().items():
@@ -52,7 +50,7 @@ def get_effects(sp_effect: ParamRow, sp_effect_type: SpEffectType, triggeree: Op
 
     return effects
 
-def get_effects_nested(sp_effect: ParamRow, sp_effects: ParamDict, add_condition: Optional[AttackCondition]) -> List[SchemaEffect]:
+def get_effects_nested(sp_effect: ParamRow, sp_effects: ParamDict, add_condition: AttackCondition | None) -> list[SchemaEffect]:
     sp_effect_type = SpEffectType(sp_effect.get("stateInfo"))
     effects = get_effects(sp_effect, sp_effect_type, init_conditions=[str(add_condition)] if add_condition else None)
 
@@ -68,13 +66,13 @@ def get_effects_nested(sp_effect: ParamRow, sp_effects: ParamDict, add_condition
 
     return effects
 
-def get_status_effect(sp_effect: ParamRow) -> Tuple[str, int]:
+def get_status_effect(sp_effect: ParamRow) -> tuple[str, int]:
     # NOTE: not identifying effects by values, relying on `stateInfo` to be correct at all times
     etype = SpEffectType(sp_effect.get("stateInfo"))
     return _SP_EFFECT_TO_STR[etype], sp_effect.get_int(_SP_EFFECT_TO_FIELD[etype])
 
-def parse_effects(row: ParamRow, sp_effects: ParamDict, *effect_referencing_fields: str, add_condition: Optional[AttackCondition]=None) -> List[Dict]:
-    effects: List[SchemaEffect] = []
+def parse_effects(row: ParamRow, sp_effects: ParamDict, *effect_referencing_fields: str, add_condition: AttackCondition | None = None) -> list[dict]:
+    effects: list[SchemaEffect] = []
 
     for effect_id in (row.get(ref_field) for ref_field in effect_referencing_fields):
         if effect_id in hardcoded_effects.get_status_effect_ranges():
@@ -85,15 +83,15 @@ def parse_effects(row: ParamRow, sp_effects: ParamDict, *effect_referencing_fiel
 
     return [e.to_dict() for e in aggregate_effects(effects)]
 
-def parse_status_effects(effect_ids: List[str], sp_effects: ParamDict) -> StatusEffects:
+def parse_status_effects(effect_ids: list[str], sp_effects: ParamDict) -> StatusEffects:
     # Getting 0th effect if value no found, bug with Antspur Rapier -- get anything to return a 0 status effect
     effects = [sp_effects.get(i, sp_effects["0"]) for i in effect_ids if i != "-1"]
     status_effects = hardcoded_effects.get_status_effect_ranges()
     return StatusEffects(**dict([get_status_effect(e) for e in effects if e.index in status_effects]))
     #return StatusEffects(**[get_status_effect(e) for e in effects if e.index in status_effects])
 
-def parse_weapon_effects(weapon: ParamRow) -> List[Dict]:
-    effects: List[SchemaEffect] = []
+def parse_weapon_effects(weapon: ParamRow) -> list[dict]:
+    effects: list[SchemaEffect] = []
 
     for field, attrib_field in attrib_fields.get(weapon=True).items():
         if weapon.get(field) != str(attrib_field.default_value):
