@@ -1,11 +1,12 @@
-from pydantic import Field, PositiveFloat, constr
+from pydantic import Field, PositiveFloat
+from pydantic.dataclasses import dataclass
 
-from erdb.typing.models import dataclass
+from erdb.typing.models import dt_config, NonEmptyStr
 from erdb.typing.models.item import Item
 from erdb.typing.models.effect import Effect
 
 
-@dataclass
+@dataclass(config=dt_config())
 class Talisman(Item):
     weight: PositiveFloat = Field(...,
         description="Weight of the Talisman",
@@ -15,7 +16,7 @@ class Talisman(Item):
         description="Effects of the Talisman",
         # example provided by Effect model
     )
-    conflicts: list[constr(min_length=1)] = Field(...,
+    conflicts: list[NonEmptyStr] = Field(...,
         description="Array of other talismans this one conflicts with.",
         example=["Crimson Amber Medallion", "Crimson Amber Medallion +1", "Crimson Amber Medallion +2"]
     )
\ No newline at end of file
